@@ -330,12 +330,16 @@ def create_register_NMT_pipe(params_template, params={},
 
     if NMT_version == "v1.2":
         # align subj to nmt
-        NMT_subject_align = pe.Node(NMTSubjectAlign(),
-                                    name='NMT_subject_align')
+        NMT_subject_align = NodeParams(
+            NMTSubjectAlign(), params=parse_key(params, "NMT_subject_align"),
+            name='NMT_subject_align')
+
     elif NMT_version == "v1.3" or NMT_version == "v2.0":
         # align subj to nmt
-        NMT_subject_align = pe.Node(NMTSubjectAlign2(),
-                                    name='NMT_subject_align')
+        NMT_subject_align = NodeParams(
+            NMTSubjectAlign2(), params=parse_key(params, "NMT_subject_align"),
+            name='NMT_subject_align')
+
     else:
         print("NMT_version {} is not implemented".format(NMT_version))
         exit()
@@ -361,7 +365,7 @@ def create_register_NMT_pipe(params_template, params={},
         list_priors = [params_template["template_head"],
                        params_template["template_seg"]]
 
-    align_masks = pe.Node(NwarpApplyPriors(), name='align_masks2')
+    align_masks = pe.Node(NwarpApplyPriors(), name='align_masks')
     align_masks.inputs.in_file = list_priors
     align_masks.inputs.out_file = list_priors
     align_masks.inputs.interp = "NN"
